Package: gtools
Title: Various R Programming Tools
Description: Functions to assist in R programming, including:
  - assist in developing, updating, and maintaining R and R packages ('ask', 'checkRVersion',
    'getDependencies', 'keywords', 'scat'),
  - calculate the logit and inverse logit transformations ('logit', 'inv.logit'),
  - test if a value is missing, empty or contains only NA and NULL values ('invalid'),
  - manipulate R's .Last function ('addLast'),
  - define macros ('defmacro'),
  - detect odd and even integers ('odd', 'even'),
  - convert strings containing non-ASCII characters (like single quotes) to plain ASCII ('ASCIIfy'),
  - perform a binary search ('binsearch'),
  - sort strings containing both numeric and character components ('mixedsort'),
  - create a factor variable from the quantiles of a continuous variable ('quantcut'),
  - enumerate permutations and combinations ('combinations', 'permutation'),
  - calculate and convert between fold-change and log-ratio ('foldchange',
    'logratio2foldchange', 'foldchange2logratio'),
  - calculate probabilities and generate random numbers from Dirichlet distributions
    ('rdirichlet', 'ddirichlet'),
  - apply a function over adjacent subsets of a vector ('running'),
  - modify the TCP_NODELAY ('de-Nagle') flag for socket objects,
  - efficient 'rbind' of data frames, even if the column names don't match ('smartbind'),
  - generate significance stars from p-values ('stars.pval'),
  - convert characters to/from ASCII codes ('asc', 'chr'),
  - convert character vector to ASCII representation ('ASCIIfy'),
  - apply title capitalization rules to a character vector ('capwords').
Version: 3.9.5
Authors@R: c(person("Gregory R.", "Warnes", role = "aut"),
             person("Ben", "Bolker", role = c("aut", "cre"),
                     email = "bolker@mcmaster.ca",
                     comment=c(ORCID="0000-0002-2127-0443")),
             person("Thomas", "Lumley", role = "aut"),
             person("Arni", "Magnusson", role = "aut"),
             person("Bill", "Venables", role = "aut"),
             person("Genei", "Ryodan", role = "aut"),
             person("Steffen", "Moeller", role = "aut"),
             person("Ian", "Wilson", role = "ctb"),
             person("Mark", "Davis", role = "ctb"),
             person("Nitin", "Jain", role="ctb"),
             person("Scott", "Chamberlain", role = "ctb"))
License: GPL-2
Depends: methods, stats, utils
URL: https://github.com/r-gregmisc/gtools
BugReports: https://github.com/r-gregmisc/gtools/issues
Language: en-US
Suggests: car, gplots, knitr, rstudioapi, SGP, taxize
RoxygenNote: 7.2.3
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2023-11-19 00:52:21 UTC; bolker
Author: Gregory R. Warnes [aut],
  Ben Bolker [aut, cre] (<https://orcid.org/0000-0002-2127-0443>),
  Thomas Lumley [aut],
  Arni Magnusson [aut],
  Bill Venables [aut],
  Genei Ryodan [aut],
  Steffen Moeller [aut],
  Ian Wilson [ctb],
  Mark Davis [ctb],
  Nitin Jain [ctb],
  Scott Chamberlain [ctb]
Maintainer: Ben Bolker <bolker@mcmaster.ca>
Repository: CRAN
Date/Publication: 2023-11-20 15:10:05 UTC
