# Generated by roxygen2: do not edit by hand

export(ASCIIfy)
export(asc)
export(ask)
export(assert)
export(assignEdgewise)
export(baseOf)
export(binsearch)
export(capture)
export(capwords)
export(checkRVersion)
export(chr)
export(combinations)
export(ddirichlet)
export(defmacro)
export(even)
export(foldchange)
export(foldchange2logratio)
export(getDependencies)
export(inv.logit)
export(invalid)
export(keywords)
export(lastAdd)
export(loadedPackages)
export(logit)
export(logratio2foldchange)
export(mixedorder)
export(mixedsort)
export(na.replace)
export(odd)
export(permutations)
export(permute)
export(quantcut)
export(rdirichlet)
export(roman2int)
export(running)
export(scat)
export(script_file)
export(script_path)
export(setTCPNoDelay)
export(smartbind)
export(split_path)
export(sprint)
export(stars.pval)
export(stat_mode)
export(strmacro)
export(unByteCode)
export(unByteCodeAssign)
importFrom(methods,is)
importFrom(methods,new)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,rgamma)
importFrom(stats,symnum)
importFrom(utils,available.packages)
importFrom(utils,flush.console)
importFrom(utils,head)
importFrom(utils,help.search)
importFrom(utils,installed.packages)
importFrom(utils,modifyList)
importFrom(utils,packageVersion)
useDynLib(gtools, .registration=TRUE)
