#' Deprecated Functions in the gtools package
#'
#' These functions are provided for compatibility with older versions of
#' gtools, and may be defunct as soon as the next release.
#'
#' gtools currently contains no deprecated functions.
#'
#' % The original help page for these functions is often % available at
#' \code{help("oldName-deprecated")} (note the quotes). % % \itemize{ % \item{}
#' % }
#'
#' @seealso \code{\link{Deprecated}}
#' @keywords misc
#' @name gtools-deprecated
NULL
