% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/checkRVersion.R
\name{checkRVersion}
\alias{checkRVersion}
\title{Check if a newer version of R is available}
\usage{
checkRVersion(quiet = FALSE)
}
\arguments{
\item{quiet}{Logical indicating whether printed output should be suppressed.}
}
\value{
Either the version number of the latest version of R, if the running
version is less than the latest version, or NULL.
}
\description{
Check if a newer version of R is available
}
\details{
This function accesses the R web site to discover the latest released
version of R.  It then compares this version to the running version.  If the
running version is the same as the latest version, it prints the message,
"The latest version of R is installed:" followed by the version number, and
returns NULL.  If the running version is older than the current version, it
displays the message, "A newer version of R is now available:" followed by
the corresponding version number, and returns the version number.

If \code{quiet=TRUE}, no printing is performed.
}
\note{
This function uses the internet to access the R project web site.
If internet access is unavailable or the R project web site is down, the function will fail.
}
\examples{

try(
   ver <- checkRVersion()
)
print(ver)
}
\seealso{
\code{\link[base]{R.Version}}
}
\author{
Gregory R. Warnes
}
\keyword{utilities}
